---
title: <span class="badge object-type-scalar"></span> DatetimeLocalNotToday
---
# <span class="badge object-type-scalar"></span> DatetimeLocalNotToday

Date & time: Datetime local (No date if today)

## Definition

```python
# Date & time: Datetime local (No date if today)
DatetimeLocalNotToday: typing.Literal["dateTimeAsLocalNoDateIfToday"] = "dateTimeAsLocalNoDateIfToday"
```
